@@ -2,14 +2,14 @@ use strict;
 use warnings;
 
 package SubClass;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 
-use base qw/BaseClass/;
+use Moose;
+BEGIN { extends 'BaseClass'; }
 
 sub bar : Bar {}
 
-use Moose;
 before affe => sub {};
 no Moose;
 
